@@ -1740,7 +1740,7 @@ advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin * vsp)
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
   volume = ABS(priv->volume_level);
-  volume_icon = volume / (100 / (NUM_VOLUME_ICONS - 1));
+  volume_icon = volume / (100 / (NUM_VOLUME_ICONS - 1) + 1);
   if (volume_icon > NUM_VOLUME_ICONS - 1)
     volume_icon = NUM_VOLUME_ICONS - 1;
 
